@@ -140,10 +140,18 @@ CALLERS = {
         {"id": "pindel", "name": "Pindel"},
         {"id": "gatk", "name": "GATK"},
         {"id": "freebayes", "name": "Freebayes"},
+        {"id": "tnscope", "name": "TNScope"},
+        {"id": "tnscope_umi", "name": "TNscope_UMI"},
+        {"id": "vardict", "name": "VarDict"},
     ],
     "cancer_sv": [
-        {"id": "manta", "name": "Manta"},
         {"id": "gatk", "name": "GATK"},
+        {"id": "manta", "name": "Manta"},
+        {"id": "dellysv", "name": "DellySV"},
+        {"id": "cnvkit", "name": "CNVkit"},
+        {"id": "ascat", "name": "ASCAT"},
+        {"id": "dellycnv", "name": "DellyCNV"},
+        {"id": "tiddit", "name": "TIDDIT"},
     ],
     "sv": [
         {"id": "gatk", "name": "GATK"},
