@@ -1,10 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"main concept of MongoDB is embed whenever possible"
-Ref: http://stackoverflow.com/questions/4655610#comment5129510_4656431
-"""
-
-from scout.constants import CLINSIG_MAP, CONSERVATION, GENETIC_MODELS, VARIANT_CALL
 
 variant = dict(
     # document_id is a md5 string created by institute_genelist_caseid_variantid:
@@ -72,7 +66,7 @@ variant = dict(
     local_frequency=float,
     local_obs_old=int,
     local_obs_hom_old=int,
-    local_obs_total_old=int,
+    local_obs_old_freq=float,
     # Predicted deleteriousness:
     cadd_score=float,
     clnsig=list,  # list of <clinsig>
