@@ -3,14 +3,25 @@ import json
 import logging
 
 from bson import ObjectId
-from flask import Blueprint, Response, flash, jsonify, redirect, render_template, request, url_for
+from flask import (
+    Blueprint,
+    Response,
+    current_app,
+    flash,
+    jsonify,
+    redirect,
+    render_template,
+    request,
+    url_for,
+)
 from flask_login import current_user
 from werkzeug.datastructures import Headers
 
 from scout.constants import CASEDATA_HEADER, CLINVAR_HEADER
 from scout.server.blueprints.variants.controllers import update_form_hgnc_symbols
-from scout.server.extensions import loqusdb, store
+from scout.server.extensions import beacon, loqusdb, store
 from scout.server.utils import institute_and_case, jsonconverter, templated
+from scout.utils.scout_requests import post_request_json
 
 from . import controllers
 from .forms import GeneVariantFiltersForm, InstituteForm, PhenoModelForm, PhenoSubPanelForm
@@ -33,13 +44,6 @@ def api_institutes():
     return jsonify(data)
 
 
-@blueprint.route("/overview")
-def institutes():
-    """Display a list of all user institutes."""
-    data = dict(institutes=controllers.institutes())
-    return render_template("overview/institutes.html", **data)
-
-
 @blueprint.route("/api/v1/institutes/<institute_id>/cases", methods=["GET", "POST"])
 def api_cases(institute_id):
     """API endpoint that returns all cases for a given institute"""
@@ -139,6 +143,24 @@ def gene_variants(institute_id):
     return dict(institute=institute_obj, form=form, page=page, **data)
 
 
+# MOST OF THE CONTENT OF THIS ENDPOINT WILL BE REMOVED AND INCLUDED INTO THE BEACON EXTENSION UNDER SERVER/EXTENSIONS
+@blueprint.route("/overview/<institute_id>/add_beacon_dataset", methods=["POST"])
+def add_beacon_dataset(institute_id):
+    """Add a dataset to Beacon for a given institute"""
+    if current_user.is_admin is False:
+        flash(
+            "Only an admin can create a new Beacon dataset",
+            "warning",
+        )
+        return redirect(request.referrer)
+
+    dataset_id = request.form.get("beacon_dataset")
+    institute_obj = store.institute(institute_id)
+
+    beacon.add_dataset(institute_obj, dataset_id)
+    return redirect(request.referrer)
+
+
 @blueprint.route("/overview/<institute_id>/settings", methods=["GET", "POST"])
 def institute_settings(institute_id):
     """Show institute settings page"""
@@ -151,10 +173,12 @@ def institute_settings(institute_id):
         return redirect(request.referrer)
 
     institute_obj = store.institute(institute_id)
-    form = InstituteForm(request.form)
+    institute_form = InstituteForm(request.form)
+
+    beacon_form = controllers.populate_beacon_form(institute_obj)
 
     # if institute is to be updated
-    if request.method == "POST" and form.validate_on_submit():
+    if request.method == "POST" and institute_form.validate_on_submit():
         institute_obj = controllers.update_institute_settings(store, institute_obj, request.form)
         if isinstance(institute_obj, dict):
             flash("institute was updated ", "success")
@@ -164,11 +188,12 @@ def institute_settings(institute_id):
 
     data = controllers.institute(store, institute_id)
     loqus_instances = loqusdb.loqus_ids if hasattr(loqusdb, "loqus_ids") else []
-    default_phenotypes = controllers.populate_institute_form(form, institute_obj)
+    default_phenotypes = controllers.populate_institute_form(institute_form, institute_obj)
 
     return render_template(
         "/overview/institute_settings.html",
-        form=form,
+        form=institute_form,
+        beacon_form=beacon_form,
         default_phenotypes=default_phenotypes,
         loqus_instances=loqus_instances,
         panel=1,
