@@ -2,13 +2,13 @@
 
 from authlib.integrations.flask_client import OAuth
 from flask_bootstrap import Bootstrap
-from flask_debugtoolbar import DebugToolbarExtension
 from flask_login import LoginManager
 from flask_mail import Mail
 
 from scout.adapter import MongoAdapter
 from scout.utils.cloud_resources import AlignTrackHandler
 
+from .beacon_extension import Beacon
 from .gens_extension import GensViewer
 from .ldap_extension import LdapManager
 from .loqus_extension import LoqusDB
@@ -16,7 +16,6 @@ from .matchmaker_extension import MatchMaker
 from .mongo_extension import MongoDB
 from .rerunner_extension import RerunnerError, RerunnerService
 
-toolbar = DebugToolbarExtension()
 bootstrap = Bootstrap()
 store = MongoAdapter()
 login_manager = LoginManager()
@@ -28,4 +27,5 @@ mongo = MongoDB()
 gens = GensViewer()
 rerunner = RerunnerService()
 matchmaker = MatchMaker()
+beacon = Beacon()
 cloud_tracks = AlignTrackHandler()
