@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
 import copy
 import logging
-from pprint import pprint as pp
 
 import pymongo
 import pytest
 
-from scout.constants import INDEXES, REV_ACMG_MAP
+from scout.constants import REV_ACMG_MAP
 from scout.exceptions import IntegrityError
 
 logger = logging.getLogger(__name__)
@@ -278,6 +277,20 @@ def test_get_cases_no_HPO(adapter, case_obj):
     assert sum(1 for i in cases) == 0
 
 
+def test_cases_no_diagnosis(adapter, case_obj, omim_term):
+    """Test filtering cases by empty diagnosis field"""
+
+    # GIVEN a case without any diagnosis:
+    assert "diagnosis_phenotypes" not in case_obj
+    adapter.case_collection.insert_one(case_obj)
+
+    # WHEN cases are filtered using OMIM terms with empty value
+    name_query = "exact_dia:"
+    cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
+    # THEN a case should be returned
+    assert sum(1 for i in cases) == 1
+
+
 def test_get_cases_no_assignees(real_adapter, case_obj):
     adapter = real_adapter
     # GIVEN an empty database (no cases)
@@ -595,6 +608,25 @@ def test_update_case_rerun_status(adapter, case_obj, institute_obj, user_obj):
     assert res["status"] == "inactive"
 
 
+def test_cases_by_diagnosis(adapter, case_obj, omim_term):
+    """Test filtering cases by assigned OMIM terms"""
+
+    # GIVEN a case with a diagnosis:
+    case_obj["diagnosis_phenotypes"] = {
+        "disease_nr": omim_term["disease_nr"],
+        "disease_id": omim_term["disease_id"],
+        "description": omim_term["description"],
+    }
+    adapter.case_collection.insert_one(case_obj)
+    # WHEN cases are filtered using OMIM terms containing that term
+    name_query = f"exact_dia:{omim_term['disease_id']},OMIM:999999"
+
+    # WHEN querying for cases with the given OMIM term
+    cases = adapter.cases(collaborator=case_obj["owner"], name_query=name_query)
+    # THEN a case should be returned
+    assert sum(1 for i in cases) == 1
+
+
 def test_cases_by_phenotype(hpo_database, test_hpo_terms, case_obj):
     adapter = hpo_database
 
