@@ -5,19 +5,19 @@ import pytest
 from scout.exceptions import IntegrityError
 
 
-def test_load_case(real_panel_database, scout_config):
+def test_load_case(real_panel_database, parsed_case):
     adapter = real_panel_database
     ## GIVEN an empty database
     existing_case = adapter.case_collection.find_one()
     assert existing_case is None
 
     ## WHEN loading a case
-    adapter.load_case(scout_config)
+    adapter.load_case(parsed_case)
 
     ## THEN assert that the case was loaded
     existing_case = adapter.case_collection.find_one()
 
-    assert existing_case["_id"] == scout_config["family"]
+    assert existing_case["_id"] == parsed_case["family"]
 
 
 def test_load_case_no_institute(adapter, case_obj):
@@ -32,16 +32,16 @@ def test_load_case_no_institute(adapter, case_obj):
         adapter.load_case(case_obj)
 
 
-def test_load_case_empty_vcf(real_panel_database, scout_config, empty_sv_clinical_file):
+def test_load_case_empty_vcf(real_panel_database, parsed_case, empty_sv_clinical_file):
     adapter = real_panel_database
     ## GIVEN an empty database
     existing_case = adapter.case_collection.find_one()
     assert existing_case is None
 
-    scout_config["vcf_sv"] = empty_sv_clinical_file
+    parsed_case["vcf_files"]["vcf_sv"] = empty_sv_clinical_file
 
     ## WHEN loading a case with a empty sv vcf
-    adapter.load_case(scout_config)
+    adapter.load_case(parsed_case)
 
     ## THEN assert that the case was loaded
     existing_case = adapter.case_collection.find_one()
