@@ -361,22 +361,6 @@ def test_phenomodel_POST_remove_subpanel_checkbox(app, user_obj, institute_obj):
     assert updated_model["subpanels"]["subpanel_x"]["checkboxes"] == {}
 
 
-def test_overview(app, user_obj, institute_obj):
-    # GIVEN an initialized app
-    # GIVEN a valid user and institute
-
-    with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
-
-        # WHEN accessing the cases page
-        resp = client.get(url_for("overview.institutes"))
-
-        # THEN it should return a page
-        assert resp.status_code == 200
-
-
 def test_institute_settings(app, user_obj, institute_obj):
     """Test function that creates institute update form and updates an institute"""
 
