@@ -1,12 +1,66 @@
 """Tests for server utils"""
 import tempfile
+from datetime import datetime
 from io import BytesIO
 
 import pytest
+from bson.objectid import ObjectId
 from flask import url_for
 
 from scout.server.links import get_variant_links
-from scout.server.utils import append_safe, find_index, html_to_pdf_file, variant_case
+from scout.server.utils import (
+    append_safe,
+    case_has_alignments,
+    case_has_mt_alignments,
+    document_generated,
+    find_index,
+    html_to_pdf_file,
+    variant_case,
+)
+
+
+def test_objectid_generated_valid_objid():
+    """Test the function that returns the timestamp of a certain Mongo ObjectId for a document"""
+    # GIVEN a database document  ObjectId
+    objid = ObjectId("6270e450615e1675f40b5ce4")
+
+    # THEN document_generated should return a timestamp
+    assert isinstance(document_generated(objid), datetime)
+
+
+def test_objectid_generated_none():
+    """Test the function that returns the timestamp of a MondoDB ObjectId when the ObjectId has wrong type"""
+
+    # GIVEN an id of different type than ObjectId
+    objid = None
+    # THEN document_generated should return None
+    assert document_generated(objid) is None
+
+
+def test_case_has_alignments(case_obj):
+    """Test function that adds info on availability of autosomal alignment files for a case"""
+
+    # GIVEN a case with no autosomal alignment files
+    for ind in case_obj["individuals"]:
+        assert ind["bam_file"] == ""
+
+    # THEN case_has_alignments should assign bam_files = False to a case
+    assert case_obj.get("bam_files") is None
+    case_has_alignments(case_obj)
+    assert case_obj["bam_files"] is False
+
+
+def test_case_has_mt_alignments(case_obj):
+    """Test function that adds info on availability of MT alignment files for a case"""
+
+    # GIVEN a case with MT alignment files
+    for ind in case_obj["individuals"]:
+        assert ind["mt_bam"]
+
+    # THEN case_has_alignments should assign mt_bams = True to a case
+    assert case_obj.get("mt_bams") is None
+    case_has_mt_alignments(case_obj)
+    assert case_obj["mt_bams"] is True
 
 
 def test_html_to_pdf_file():
